"""Version information for ZeroPhix."""

__version__ = "0.1.20"

__version_info__ = tuple(int(i) for i in __version__.split("."))
__author__ = "ZeroPhix Team"
__license__ = "Apache-2.0"
__copyright__ = "Copyright 2025-2026 ZeroPhix Team"
__url__ = "https://github.com/yourorg/zerophix"
__description__ = "Enterprise-grade PII/PSI/PHI redaction service: multilingual, customizable, and privacy-first"
